<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 est un logiciel libre mais son développement prend du temps.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>D&apos;avance merci pour vos &lt;a href=&apos;%1&apos;&gt;dons&lt;/a&gt; nécessaires à la poursuite du développement de %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Publié sous licence &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Ce que vous avez toujours voulu savoir sur %1 sans jamais oser le demander</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Vous pouvez également essayer mes autres applications telles que:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, une application Youtube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, un lecteur de musique basé sur YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduisez %1 dans votre langue maternelle en utilisant %2</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Acheter %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>En savoir plus</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>En savoir plus</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Retour</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Retour</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenue dans &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 doit scanner votre collection musicale.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Utiliser la bibliothèque iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Utiliser %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Choisir un répertoire...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 va se connecter à Last.fm et transmettre le nom de l&apos;artiste et les titres de l&apos;album pour récupérer la couverture, la biographie et bien plus.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Si vous estimez qu&apos;il y a un risque pour votre vie privée, vous pouvez quitter maintenant.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Où est stockée votre musique?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Sélectionnez l&apos;emplacement de votre collection musicale.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Localisez votre collection</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Une analyse est déjà en cours</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 analyse votre collection musicale.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 utilise &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; pour cataloguer votre musique.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>La durée de l&apos;analyse dépend de la taille de votre collection et de la vitesse de connexion.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Prenez le temps d&apos;un café...</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <source>Please license %1</source>
        <translation>Veuillez obtenir une licence pour %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Cette version démo a expiré.</translation>
    </message>
    <message>
        <source>This demo will expire in %1 days.</source>
        <translation>Cette version démo s&apos;expire dans %1 jours.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>En achetant la version complète, vous supporterais aussi le le grand travail que j&apos;ai investi à la création de %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Utilisez la version démo</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obtenir la version complète</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Déposer ici pour ajouter à la liste de lecture</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Artistes</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albums</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Répertoires</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Lecture/Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Arrêter après la piste en cours</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Piste suivante</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Piste précédente</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Augmenter le volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Baisser le volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silence</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Recherche en avant</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Recherche en arrière</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Retour</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Aller à la vue précédente</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Infos</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Voir les infos de la piste en cours</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>P&amp;récédent</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Aller à la piste précédente</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>Suiva&amp;nte</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Aller à la piste suivante</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Lec&amp;ture</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Démarrer la lecture</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Mettre en plein écran</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Retirer</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Retirer les pistes sélectionnées de la liste de lecture</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mo&amp;nter</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Monter les pistes sélectionnées dans la liste de lecture</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Descendre</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Descendre les pistes sélectionnées dans la liste de lecture</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Au revoir</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Changer le répertoire de la collection...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Sélectionner un autre répertoire de collection</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Site &amp;Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 sur le Web</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Faire un &amp;don</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Merci de contribuer à la poursuite du développement de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;À propos</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Infos à propos de %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>Effa&amp;cer</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Enlever toutes les pistes de la liste de lecture</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>A&amp;léatoire</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Lecture aléatoire de la liste de lecture</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Répéter</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Revient à la première piste lorsque la liste de lecture est finie</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silence</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Application</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Lecture</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>L&amp;iste de lecture</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ai&amp;de</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Presser %1 pour monter le volume, %2 pour le baisser</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Ouverture de %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Mise à jour de la collection...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Mise à jour de la collection - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>La collection est à jour</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Erreur fatale: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erreur: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Quitter le &amp;mode plein écran</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Durée restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume à %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Le volume est coupé</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Le volume est restauré</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obtenir la version complète</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 version %2 est maintenant disponible.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Me le rappeler plus tard</translation>
    </message>
    <message>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation>Pour obtenir la version mise à jour, téléchargez à nouveau %1 à partir du lien que vous avez reçu par e-mail et réinstallez la.</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Mettre à jour</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenêtre</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Réduire</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Acheter %1 …</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Arrêter après ce morceau</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Déposez des éléments ici</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Liste de lecture terminée</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Ce n&apos;est que la version de démostration de %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Elle ne permet que de jouer quelques chansons pour vous faire une idée de ses possibilités.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuer</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obtenir la version complète</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Cette version de démo limite le nombre de morceaux à %1 dans la liste de lecture.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>La liste de lecture est vide</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 pistes, pour une durée totale de %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Recherche</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Votre recherche n&apos;a donné aucun résultat.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Pistes</translation>
    </message>
</context>
</TS>